@@ -80,6 +80,10 @@ void FBRequest::connect()
     request.setUrl(QUrl(url));
     request.setRawHeader("User-Agent", kUserAgent);
 
+#if QT_VERSION >= 0x040600
+    request.setAttribute(QNetworkRequest::HttpPipeliningAllowedAttribute, true);
+#endif
+
     /* from the Qt docs on QNetworkAccessManager:
        QNetworkAccessManager by default does not have a set cache.
        Qt provides a simple disk cache, QNetworkDiskCache, which can be used.
@@ -113,7 +117,7 @@ void FBRequest::connect()
 QString FBRequest::md5(const QString& aData)
 {
     QByteArray byteArray;
-    byteArray.insert(0, aData);
+    byteArray.insert(0, aData.toUtf8());
 
     QByteArray md5Hash = QCryptographicHash::hash(byteArray,QCryptographicHash::Md5 ).toHex();
     QString returnString ( md5Hash );
@@ -195,7 +199,7 @@ QString FBRequest::generateSig()
 void FBRequest::generatePostBody( QByteArray& body )
 {
     QString endLine = "\r\n--" + kStringBoundary + "\r\n";
-    body.append( "--" + kStringBoundary + "\r\n" ) ;
+    body.append( "--" + kStringBoundary.toUtf8() + "\r\n" ) ;
 
 
     DictionaryIterator i (iParams);
@@ -206,7 +210,7 @@ void FBRequest::generatePostBody( QByteArray& body )
 
         body.append("Content-Disposition: form-data; name=\"" + i.key().toUtf8() + "\"\r\n\r\n" );
         body.append(i.value().toUtf8());
-        body.append(endLine);
+        body.append(endLine.toUtf8());
     }
 
 
@@ -224,7 +228,7 @@ void FBRequest::generatePostBody( QByteArray& body )
         }
 
         body.append(iDataParam);
-        body.append(endLine);
+        body.append(endLine.toUtf8());
 
     }
 }
